@@ -151,7 +151,7 @@ class Calltracking extends \FreePBX_Helpers implements \BMO
 
         $this->astman->database_put('zruchnaio/calltracking', 'configured', gmdate(\DATE_ATOM));
         $this->putSequenceDatabaseValue('zruchnaio/calltracking/clients', $clientNameList);
-        $this->putSequenceDatabaseValue('zruchnaio/calltracking/dids', $didNameSet);
+        $this->putSequenceDatabaseValue('zruchnaio/calltracking/dids', array_keys($didNameSet));
     }
 
     /**
@@ -164,7 +164,7 @@ class Calltracking extends \FreePBX_Helpers implements \BMO
         }
 
         $clientNameList = $this->getClientsConfiguration();
-        $didNameList = $this->getClientsConfiguration();
+        $didNameList = $this->getDidsConfiguration();
 
         $clientDidsMap = array();
         foreach ($didNameList as $didName) {
